function res = PSO_function(popSize,imax, LB, UB)
% popSize = number of particles
% imax = number of iterations
% LB = lower boundrary (in 2D LB=[xmin ymin])
% UB = upper boundrary (in 2D UB=[xmax ymax])

% starting timer
tic

% initilizing of variables
c1 = 2;
c2 = 2;
nvar = 2; %dimention of the problem
dt = 0.2; %tuning, how "aggressive" the algorithm is  
fitness = zeros(popSize,1);
    
% creates the initial population
x = PSO_initialPop(popSize,nvar,LB,UB); 
    
% finding the result for the initial population
% this loop was later changed to parfor/cloudfor
for i = 1 : popSize
	fitness(i,1) = pde_model_commandline(x(i,1),x(i,2));
end
    
% initilation more variables
pb = fitness; %personal best for all particles
xPb = x; %the corresponding x,y placement for pb
v = zeros(popSize,length(LB)); %current velocity
[gb,iGB]=max(fitness); %starting global best (gb)
xGb = x(iGB,:); %starting global best position

% doing the iterations
for i =1:imax
	[w = PSO_inertialWeight(i,imax)
  
	% finding current solution for all particles
	% this loop was later changed to parfor/cloudfor
	for j = 1 : popSize
		fitness(j,1)=pde_model_commandline(x(j,1),x(j,2));
	end

	% compare current to personal- and global bests
	for j = 1 : popSize
		% compares present position to personal best
		if fitness(j,1) > pb(j,1) 	
			pb(j,1) = fitness(j,1); %updates p. best value
			xPb(j,:) = x(j,:); %updates p. best position
		end
		% compares current postition to the global best
		if fitness(j,1) > gb  
			gb = fitness(j,1); %updates global best value
			xGb = x(j,:); %updates gb position
		end
	end

	% updating velocity and position
	for  k = 1 : popSize
		v(k,:) = w*v(k,:) + c1*rand*(xPb(k,:) - x(k,:)) +  c2*rand*(xGb - x(k,:)); %new velocity
		x(k,:) = x(k,:) + dt*v(k,:); %new position
       
		% dealing with particles outside boundries
		for m = 1 : length(LB)
			if (x(k,m) < LB(m))
				x(k,m) = LB(m);
				v(k,m) = 0;
			elseif (x(k,m) > UB(m))
				x(k,m) = UB(m);
				v(k,m) = 0;
			end
		end
	end
end

% stopping timer
time=toc;

% plotting final solution
pde_model_commandline(xGb(1),xGb(2),i,1);

% returning runtime and the global best values
res=[time gb xGb(1) xGb(2)]
    
end 