function Torque = pde_model_CaseII_commandline_2(hmagn, wmagn, i, ifPlot)

%parameters for the geometry
r_rotor=5; %radius rotor
dr_airgap=2; %width airgap
dr_stator=3; %width stator
width_slot=4; %in degrees
depth_slot=0.5; 
ant_slots=12; %number of slots
%radius for torque-calculation circle
r_circle_torque=r_rotor+dr_airgap-0.03; 
%at what degrees the slots are placed
grader_slot=[15 45 ... 345]; 

%the currents in the three phases r, s and t
curr_r=2e3;
curr_s=4e3;
curr_t=2e3;

%input boundary conditions
q_neumann='0'; %q, Neumann
g_neumann='0'; %g, Neumann
h_dirichlet='1'; %h, Dirichlet
r_dirichlet_magnet='1.20000*x'; %r, Dirichlet 
r_dirichlet_outer='0'; %r, Dirichlet

% Material parameters
mu_0=4*pi*1e-7; %Permeability vakuum
mu_iron=4000*mu_0; %Permeability iron
mu_copper=mu_0; %Permeability copper

% Geometry description:
 
% Defining all the circles 
area_rotor = [4 0 0 r_rotor r_rotor 0 0 0 0 0 0 0];
[similar for the other circles]

% Defining all the slots 
slots=zeros(12,ant_slots);
slots(1,:)=2;
slots(2,:)=4;
slots(3,:)=cosd(grader_slot-(width_slot/2))*(r_rotor+dr_airgap-0.001);
slots(7,:)=sind(grader_slot-(width_slot/2))*(r_rotor+dr_airgap-0.001);
[row 4-6,8-10 contains x,y for rest of the corners]

% The polynoms to make the magnet widht 
%angle in rad from x-axis to magnet "start"
ang_magn=((pi*r_rotor-wmagn)/r_rotor)/2; 
y=sin(ang_magn)*(r_rotor+dr_airgap+dr_stator);
x=cos(ang_magn)*(r_rotor+dr_airgap+dr_stator);
area_neg_tri = [2 5 0 -x -10 -10 -x 0 y y -y -y];
area_pos_tri = [2 5 0 x 10 10 x 0 y y -y -y];

% Making the geometry matrix
gdm = [area_rotor' area_air' area_stator' circle_torque' slots area_magnet' area_neg_tri' area_pos_tri'];
[g, bt] = decsg(gdm, '(E3+P1+P2+P3+P4+P5+P6+P7+P8+P9+S1+S2+S3+E2+E5)-(E4-E1-T1-T2)',['E1'; 'E2'; [labels corresponding to gdm] ; 'T2']');

% Mesh generation:
hmax=0.2;
[p,e,t]=initmesh(g,'Hmax',hmax,'MesherVersion','R2013a');

%Get edge labels for outer circle and magnet
%find index in p to a known point at all outer boundaries
index_outer_1=intersect(find(p(2,:)==10),(find(abs(p(1,:))<0.01)));
[dping the same for p(1,:) and -10]

%find index in p to a known point at all long sides of magnets
index_bottommagn_bottom=intersect(find(p(2,:)==-r_rotor),(find(p(1,:)<0.001)));
index_bottommagn_top=intersect(find(round(p(2,:)*100000)==-(round((r_rotor+hmagn)*100000))),(find(abs(p(1,:))<0.01)));
[same for top magnet]

%find index in p to a known point at all long sides of magnets by finding index to center and recognicing that the short sides always has same boundary number plus/minus 1 as the four that meats in the center
index_center=intersect(find(p(2,:)==0),(find(p(1,:)==0)));

%finding boundary labels to the edges by finding the index in the first or second row of the e matrix. the label is in row 5.
%labels outer circle
label_outer_1=e(5,(find(e(1,:)==index_outer_1)));
label_outer_2=e(5,(find(e(1,:)==index_outer_1)));
[similar for index_outer_2, ..._3 and ..._4]

%labels long sides magnets (must have two since the long sides divide into two segments when long)
label_topmagn_bottom=e(5,(find(e(1,:)==index_topmagn_bottom)));
label_topmagn_bottom_2=e(5,(find(e(2,:)==index_topmagn_bottom)));
[similar for the rest of the indices]

%labels short sides magnets
label_center1=e(5,(find(e(1,:)==index_center)));
label_center2=e(5,(find(e(2,:)==index_center)));

label_topmagn_3=label_center1(1)+1;
[similar for the 3 others]

%making boundary condition matrix b (doc pdebound)
ne = size(g,2); % number of edges

N=1;%number of PDEs
M=1;%number of Dirichlet conditions

%assume only Dirichlet boundary contitions
b=zeros((6+numel(q_neumann)+numel(g_neumann)+numel(h_dirichlet)+numel(r_dirichlet_magnet)),ne);
for k = 1:ne
    switch k
        %setting boundary conditions for outer circle
        case {[any of labels for outer circle]}
           b(:,k)=[1;1;1;1;1;1;'0';'0';'1';'0';0;0;0;0;0;0;0;0];
        %setting boundary conditions for magnets
        case {[any of labels for magnets]}
            b(:,k)=[1;1;1;1;1;length_r;'0';'0';'1';r_dirichlet_magnet(1);...;r_dirichlet_magnet(9)];
        %setting the rest of the edges to having none 
        otherwise
            b(:,k)=[0;1;1;1;1;1;'0';'0';'0';'0';0;0;0;0;0;0;0;0];
    end
end

% Setting up PDE coefficients

%same order as in gdm
current=[0 0 0 0 curr_t curr_t ... -curr_r 0 0 0];
f_temp=bt*current';

%material constants
iron=1/mu_iron;
air=1/mu_0;
copper=1/mu_copper;

%same order as in gdm
material=[iron air iron ... iron];
c_temp=bt*material';

%making the f and c variables. Did not find a better way to do this.
f=num2str(f_temp(1));
c=num2str(c_temp(1));

for i=2:length(f_temp)
    f=strcat(f,'!',num2str(f_temp(i)));
    c=strcat(c,'!',num2str(c_temp(i)));
end

a=0; %seems to be 0 for all magnetostatic problems

%Solving PDE (u is magnetic potential)
u = assempde(b, p, e, t, c, a, f); 

%find gradient to u at triangle MIDPOINT
[ux,uy] = pdegrad(p,t,u);

%compute gradient of A in NODES 
ux_node=pdeprtni(p,t,ux);
uy_node=pdeprtni(p,t,uy);

%Making the B-field at triangle midpoint ref[1]
B=[uy;-ux];

%absolute value of B at node points
absB=sqrt((ux_node.^2)+(uy_node.^2));

%Plotting solutions
if ifPlot==1
    %plot geometri og contour-plot
    figure(1)
    set(gcf,'name','Contour plot of B-field') 
    hold on
    pdegplot(g);    
    pdeplot(p,e,t,'xydata',absB,'contour','on','levels',20); 
    hold off
    
    [more plots]
end

% Calsulating magnet area
TotalMagnetArea=(((hmagn+r_rotor)^2*((pi/2)*ang_magn))-(r_rotor)^2*((pi/2)*ang_magn))*2;

%finds all boundary labels to the "torque circle"
index_temp=intersect(find(round(p(1,:)*100)==round(0*100)),find(round(p(2,:)*100)==round(r_circle_torque*100)));
label_circle_torque_1=e(5,(find(e(1,:)==index_temp)));
label_circle_torque_1x=e(5,(find(e(2,:)==index_temp)));
[similar in the three other directions as well]

%finds index i p to all nodes at the "torque circle"
node_points_circle_torque=[];
for k = 1:length(e(1,:))
    switch e(5,k)
        case {label_circle_torque_1 ... label_circle_torque_4x}
            node_points_circle_torque=[node_points_circle_torque e(1,k)];
    end
end

%calculation of tensor and force
sum_f=0;
for n=(node_points_circle_torque);
    %tensor 
    T=[(Bx(n)^2-0.5*absB(n)^2) Bx(n)*By(n); By(n)*Bx(n) (By(n)^2-0.5*absB(n)^2)];
    %force in each point
    f=(1/mu_0)*T*[(p(1,n)/r_circle_torque);(p(2,n)/r_circle_torque)];
    %force causing axial torque
    df=sqrt((dot(tS,f)*[nS(2);-nS(1)](1))^2+(dot(tS,f)*[nS(2);-nS(1)](2))^2);
    %summing up force contributions
    sum_f=sum_f+df;
end
%multiplying with average length between nodes
F=sum_f*((r_circle_torque*2*pi)/length(node_points_circle_torque));
Torque=F*r_circle_torque*1e-4; %due to scaling
end