function Bfield = pde_model_commandline(xmagn, ymagn, i, ifPlot)

% Material parameters
mu_0=4*pi*1e-7; %Permeability vakuum
mu_iron=4000*mu_0; %Permeability iron

% Geometry description, defining the different objects
area = [3 4 -1 1 1 -1 0.5 0.5 -0.8 -0.8];
iron_1 = [3 4 -1 1 1 -1 0.5 0.5 0.45 0.45];
iron_2 = [3 4 -0.4 0.4 0.4 -0.4 0.45 0.45 0.2 0.2];
magnet = [3 4 xmagn xmagn+0.6 xmagn+0.6 xmagn ymagn+0.3 ymagn+0.3 ymagn ymagn];
    
%making the geometry matrix and plots it
gdm = [area; iron_1; iron_2; magnet]';
g = decsg(gdm, 'R1-R4+R3+R2', ['R1'; 'R2'; 'R3'; 'R4']');

% Mesh generation
hmax=0.02;
[p,e,t]=initmesh(g,'Hmax',hmax,'MesherVersion','R2013a');

% Boundary conditions (b was exported from gui)
b=[0 0 0 1 1 1 1 ... 41 0 0 0];

% PDE coefficients
f='0!0!0';
c=strcat(num2str(1/mu_iron),'!',num2str(1/mu_iron),'!',num2str(1/mu_0));
a='0.0!0.0!0.0';

%Solving PDE
u = assempde(b, p, e, t, c, a, f); %u is magnetic potential

%finding gradient to u at triangle MIDPOINT
[ux,uy] = pdegrad(p,t,u);

%Making the B-field at triangle midpoint
B=[uy;-ux];

%compute gradient of A in NODES
ux_node=pdeprtni(p,t,ux);
uy_node=pdeprtni(p,t,uy);

%absolute value of B is the length of vector at NODES
absB=sqrt((ux_node.^2)+(uy_node.^2));

%Plotting solutions
if ifPlot==1
    %plot geometri og contour-plot
    figure(1)
    set(gcf,'name','Contour plot of B-field') 
    hold on
    pdegplot(g, 'subdomainLabels','on');    
    pdeplot(p,e,t,'xydata',absB,'contour','on','levels',15); 
    hold off
    [more plotting]
end

%finding solution in (-0.4,0.2)
index=intersect(find(p(2,:)==0.2),(find(p(1,:)==-0.4))); %index in solution vector

if isempty(index)
    Bfield=0;
elseif xmagn==-0.2
    Bfield=0;
else
    Bfield=absB(index);
end
end